import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';
import './tivio_sections_widget.dart';

class TivioChannelsWidget extends StatefulWidget {
  final Tivio _tivio;
  final String _widgetId;

  TivioChannelsWidget(this._tivio, this._widgetId);

  @override
  createState() => _TivioChannelsWidgetState();
}

class _TivioChannelsWidgetState extends State<TivioChannelsWidget> {
  List<TivioDataChannel> _channels = [];
  TivioDataStream<TivioDataPagination<TivioDataChannel>> _channelsStream;
  TivioDataChannel _selectedChannel;

  @override
  void initState() {
    super.initState();
    fetchChannels();
  }

  fetchChannels() {
    _channelsStream = widget._tivio.subscribeToChannelsInWidget(widgetId: widget._widgetId);
    _channelsStream.stream.listen((event) {
      setState(() {
        _channels = event.records;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(title: Text('Tivio Demo')),
        body: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              children: [
                ..._channels
                    .map(
                      (channel) => ElevatedButton(
                        style: ElevatedButton.styleFrom(
                          primary: (_selectedChannel != null && _selectedChannel.id == channel.id)
                              ? Colors.cyan
                              : Colors.white24,
                        ),
                        onPressed: () => setState(() {
                          _selectedChannel = channel;
                        }),
                        child: Text(channel.name),
                      ),
                    )
                    .toList()
              ],
            ),
            Container(
              child: (_selectedChannel != null)
                  ? TivioSectionsWidget(
                      widget._tivio,
                      _selectedChannel.id,
                      key: Key(_selectedChannel.id),
                    )
                  : Text('Choose a channel'),
            ),
          ],
        ));
  }

  @override
  void dispose() {
    _channelsStream.close();
    super.dispose();
  }
}
