import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:tivio_sdk/tivio.dart';
import 'package:tivio_sdk/player/controls/better_player_control.dart';
import 'package:tivio_sdk/player/controls/better_player_ui_press_controls.dart';
import 'package:tivio_sdk/player/tivio_player_colors.dart';

class TivioPlayerControlsWidget extends StatefulWidget {
  @override
  createState() => _TivioPlayerControlsWidgetState();
}

class _TivioPlayerControlsWidgetState extends State<TivioPlayerControlsWidget> {
  bool isInFullscreen = true;

  @override
  initState() {
    super.initState();
    enterFullScreen();
  }

  enterFullScreen() {
    SystemChrome.setPreferredOrientations([DeviceOrientation.landscapeLeft]);

    setState(() {
      isInFullscreen = true;
    });
  }

  exitFullScreen() {
    SystemChrome.setPreferredOrientations([DeviceOrientation.portraitUp]);

    setState(() {
      isInFullscreen = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        child: AspectRatio(
          aspectRatio: 16 / 9,
          child: Container(
            color: Colors.lightBlueAccent,
            child: Stack(
              children: [
                BetterPlayerControlUi(
                  controls: BetterPlayerUiPressControls(
                    onPlayPressed: () => null,
                    onPausePressed: () => null,
                    onForwardPressed: () => null,
                    onBackwardPressed: () => null,
                    onEnterFullscreenPressed: () => enterFullScreen(),
                    onExitFullscreenPressed: () => exitFullScreen(),
                    onSeekingStarted: () => null,
                    onSeekingEnded: (Duration position) => null,
                  ),
                  tivioPlayerColors: TivioPlayerColors(),
                  tivioPlayerLayout: TivioPlayerLayout(
                    topLeft:  TivioPlayerLayoutTopLeft.custom,
                    topLeftCustomWidget: InkWell(
                      onTap: () => print('Tap on custom icon'),
                      child: Icon(
                        Icons.ac_unit,
                        color: Colors.white,
                        size: 48,
                      ),
                    ),
                    topRight: TivioPlayerLayoutTopRight.custom,
                    topRightCustomWidget: InkWell(
                      onTap: () => print('Tap on custom icon'),
                      child: Icon(
                        Icons.close,
                        color: Colors.white,
                        size: 48,
                      ),
                    ),
                  ),
                  isPlaying: true,
                  isBuffering: false,
                  isInFullscreen: isInFullscreen,
                  progress: Duration(seconds: 30),
                  duration: Duration(seconds: 60),
                  resetHideUiAfterDelay: () => null,
                  overwriteProgress: (Duration overwrittenProgress) => null,
                  buffered: [],
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
