import 'package:flutter/material.dart';
import 'package:nav_router/nav_router.dart';
import 'package:tivio_sdk/tivio.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'tivio_player_play_by_controller.dart';
import 'tivio_player_play_immediately.dart';

class PlayerWithTivioIntegrationIndex extends StatelessWidget {
  final Tivio tivio;

  PlayerWithTivioIntegrationIndex({
    this.tivio,
  });

  @override
  Widget build(BuildContext context) {
    var demoVideo = getDemoVideoFromEnv();

    return Scaffold(
      appBar: AppBar(
        title: Text('Player with tivio integration'),
      ),
      body: Flex(
        direction: Axis.vertical,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          TextButton(
            onPressed: () => routePush(
                TivioPlayerPlayByController(
                  tivio: tivio,
                  videoId: demoVideo['videoId'],
                  videoUrl: demoVideo['videoUrl'],
                ),
                RouterType.material),
            child: Text('Play by controller'),
          ),
          TextButton(
            onPressed: () => routePush(
                TivioPlayerPlayImmediately(
                  tivio: tivio,
                  videoId: demoVideo['videoId'],
                  videoUrl: demoVideo['videoUrl'],
                ),
                RouterType.material),
            child: Text('Play immediately'),
          ),
        ],
      ),
    );
  }

  getDemoVideoFromEnv() {
    var result = Map<String, String>();
    result['videoId'] = DotEnv().env['TIVIO_DEMO_VIDEO_ID'];
    result['videoUrl'] = DotEnv().env['TIVIO_DEMO_VIDEO_URL'];

    return result;
  }
}
