import 'package:logger/logger.dart' as DartLogger;
import 'package:sentry/sentry.dart';
import 'package:tivio_sdk/tivio.dart';
import 'enums/tivio_log_levels.dart';

class Logger {
  static final Logger _instance = Logger._internal();
  DartLogger.Logger? _logger;

  factory Logger() {
    return _instance;
  }

  Logger._internal();

  static DartLogger.Level tivioLogLevelsToDartLoggerLevels(TivioLogLevels tivioLogLevel) {
    switch (tivioLogLevel) {
      case TivioLogLevels.nothing:
        return DartLogger.Level.nothing;
      case TivioLogLevels.info:
        return DartLogger.Level.info;
      case TivioLogLevels.debug:
        return DartLogger.Level.debug;
      case TivioLogLevels.error:
        return DartLogger.Level.error;
      case TivioLogLevels.verbose:
        return DartLogger.Level.verbose;
      case TivioLogLevels.warning:
        return DartLogger.Level.warning;
    }
  }

  init({
    required TivioLogLevels logLevel,
    required String sentryDsn,
    required bool development,
  }) async {
    if (_instance._logger == null) {
      print('Initializing tivio logger with level: $logLevel');
      _instance._logger = DartLogger.Logger(level: Logger.tivioLogLevelsToDartLoggerLevels(logLevel));

      if (!development) {
        print('Initializing sentry for tivio');

        await Sentry.init(
          (options) {
            options.dsn = sentryDsn;
          },
        );
      }
    }
  }

  info(dynamic message) {
    _getLogger()!.i(message);
  }

  debug(dynamic message) {
    _getLogger()!.d(message);
  }

  verbose(dynamic message) {
    _getLogger()!.v(message);
  }

  warning(dynamic message) {
    _getLogger()!.w(message);
    if (Sentry.isEnabled) {
      Sentry.captureMessage('$message', level: SentryLevel.warning);
    }
  }

  error(dynamic message) {
    _getLogger()!.e(message);
    if (Sentry.isEnabled) {
      Sentry.captureMessage('$message', level: SentryLevel.error);
    }
  }

  DartLogger.Logger? _getLogger() {
    if (_logger == null) {
      throw Exception('Logger is not initialized.');
    }

    return _logger;
  }
}
