import 'dart:async';
import 'package:flutter/material.dart';
import 'package:better_player/better_player.dart';
import 'package:tivio_sdk/player/tivio_player_input_source.dart';

class SkipAdButton extends StatelessWidget {
  final int seconds;
  final bool isClickable;
  final Function? onClick;

  SkipAdButton({
    required this.seconds,
    this.onClick,
    this.isClickable = false,
  });

  @override
  Widget build(BuildContext context) {
    return Positioned.fill(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.end,
        verticalDirection: VerticalDirection.up,
        children: [
          Padding(
            padding: EdgeInsets.only(left: 0, top: 10, right: 20, bottom: 20),
            child: RawMaterialButton(
              onPressed: (isClickable && onClick != null) ? () => onClick!() : null,
              shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8)),
              fillColor: (isClickable) ? Colors.white : Color.fromRGBO(51, 51, 51, 1),
              child: Container(
                width: 160,
                height: 50,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    Text(
                      (isClickable) ? 'Přeskočit reklamu' : 'Přeskočit za $seconds s',
                      style: TextStyle(
                        fontSize: 16,
                        fontWeight: FontWeight.bold,
                        color: (isClickable) ? Colors.black : Colors.white,
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
          Padding(
            padding: EdgeInsets.only(right: 20),
            child: (!isClickable)
                ? Text(
                    'Video bude pokračovat po reklamě',
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 12,
                      fontWeight: FontWeight.bold,
                      shadows: [
                        Shadow(
                          blurRadius: 10,
                          color: Color.fromRGBO(0, 0, 0, 0.5),
                          offset: Offset(0, 0),
                        ),
                      ],
                    ),
                  )
                : null,
          ),
        ],
      ),
    );
  }
}

class BetterPlayerAdControls extends StatefulWidget {
  StreamController<BetterPlayerEvent> eventPlayerStream;
  Function onClick;
  TivioPlayerAdSource source;

  BetterPlayerAdControls({
    required this.eventPlayerStream,
    required this.source,
    required this.onClick,
  });

  @override
  createState() => _BetterPlayerAdControlsState();
}

class _BetterPlayerAdControlsState extends State<BetterPlayerAdControls> {
  Duration? progress = Duration();
  StreamSubscription? subscription;

  @override
  void initState() {
    super.initState();

    if (subscription != null) {
      subscription!.cancel();
    }

    subscription = widget.eventPlayerStream.stream.listen((event) {
      switch (event.betterPlayerEventType) {
        case BetterPlayerEventType.progress:
          setState(() {
            progress = event.parameters!['progress'];
          });
          break;
        default:
          break;
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    int secondsToSkip = widget.source.skipDelay!.inSeconds - progress!.inSeconds;
    bool isClickable = widget.source.isSkippable! && secondsToSkip <= 0;

    return SkipAdButton(
      seconds: secondsToSkip,
      isClickable: isClickable,
      onClick: widget.onClick,
    );
  }

  @override
  void dispose() {
    if (subscription != null) {
      subscription!.cancel();
    }
    super.dispose();
  }
}
