import 'package:better_player/better_player.dart';
import 'package:better_player/src/controls/better_player_progress_colors.dart';
import 'package:better_player/src/video_player/video_player_platform_interface.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class BetterPlayerMaterialVideoProgressBar extends StatefulWidget {
  BetterPlayerMaterialVideoProgressBar({
    BetterPlayerProgressColors? colors,
    required this.onDragEnd,
    required this.onDragStart,
    required this.progress,
    required this.duration,
    required this.onSeekingEnded,
    required this.buffered,
    required this.isPlaying,
    Key? key,
  })  : colors = colors ?? BetterPlayerProgressColors(playedColor: Color.fromRGBO(255, 0, 0, 0.7)),
        super(key: key);

  final BetterPlayerProgressColors colors;
  final Function() onDragStart;
  final Function(bool wasPlaying) onDragEnd;
  final Function(Duration position) onSeekingEnded;
  final Duration progress;
  final Duration duration;
  final List<DurationRange> buffered;
  final bool isPlaying;

  @override
  _VideoProgressBarState createState() {
    return _VideoProgressBarState();
  }
}

class _VideoProgressBarState extends State<BetterPlayerMaterialVideoProgressBar> {
  bool _controllerWasPlaying = false;

  Duration get duration => widget.duration;

  List<DurationRange> get buffered => widget.buffered;

  @override
  Widget build(BuildContext context) {
    void seekToRelativePosition(Offset globalPosition) {
      final box = context.findRenderObject() as RenderBox;
      final Offset tapPos = box.globalToLocal(globalPosition);
      final double relative = tapPos.dx / box.size.width;

      if (relative > 0) {
        final Duration position = duration * relative;
        widget.onSeekingEnded(position);
      }
    }

    return GestureDetector(
      onHorizontalDragStart: (DragStartDetails details) {
        _controllerWasPlaying = widget.isPlaying;
        widget.onDragStart();
      },
      onHorizontalDragUpdate: (DragUpdateDetails details) {
        seekToRelativePosition(details.globalPosition);
      },
      onHorizontalDragEnd: (DragEndDetails details) {
        widget.onDragEnd(_controllerWasPlaying);
      },
      onTapDown: (TapDownDetails details) {
        seekToRelativePosition(details.globalPosition);
      },
      child: Center(
        child: Container(
          height: 30,
          width: MediaQuery.of(context).size.width,
          color: Colors.transparent,
          child: CustomPaint(
            painter: _ProgressBarPainter(
              duration,
              buffered,
              widget.colors,
              widget.progress,
            ),
          ),
        ),
      ),
    );
  }
}

class _ProgressBarPainter extends CustomPainter {
  final Duration duration;
  final Duration progress;
  final List<DurationRange> buffered;
  final BetterPlayerProgressColors colors;

  _ProgressBarPainter(this.duration, this.buffered, this.colors, this.progress);

  @override
  bool shouldRepaint(CustomPainter painter) {
    return true;
  }

  @override
  void paint(Canvas canvas, Size size) {
    const height = 10.0;

    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromPoints(
          Offset(0.0, size.height / 2),
          Offset(size.width, size.height / 2 + height),
        ),
        const Radius.circular(4.0),
      ),
      colors.backgroundPaint,
    );

    final double playedPartPercent = progress.inMilliseconds / duration.inMilliseconds;
    final double playedPart = playedPartPercent > 1 ? size.width : playedPartPercent * size.width;

    for (final DurationRange range in buffered) {
      final double start = range.startFraction(duration) * size.width;
      final double end = range.endFraction(duration) * size.width;
      canvas.drawRRect(
        RRect.fromRectAndRadius(
          Rect.fromPoints(
            Offset(start, size.height / 2),
            Offset(end, size.height / 2 + height),
          ),
          const Radius.circular(4.0),
        ),
        colors.bufferedPaint,
      );
    }

    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromPoints(
          Offset(0.0, size.height / 2),
          Offset(playedPart, size.height / 2 + height),
        ),
        const Radius.circular(4.0),
      ),
      colors.playedPaint,
    );

    canvas.drawCircle(
      Offset(playedPart, size.height / 2 + height / 2),
      0,
      colors.handlePaint,
    );
  }
}
